@@ -4,11 +4,8 @@
     sijax.response.BaseResponse
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    Provides the BaseResponse class, which is the default class
-    used to create response objects from for regular Sijax functions.
-    The response class is the way for Sijax functions (handlers) to
-    pass information back to the browser. They do this by calling
-    various methods, which queue commands until they're sent to the browser.
+    Provides the BaseResponse class, which is the base class
+    used to create response objects for Sijax functions.
 
     :copyright: (c) 2011 by Slavi Pantaleev.
     :license: BSD, see LICENSE.txt for more details.
@@ -21,6 +18,10 @@ from types import GeneratorType
 
 
 class BaseResponse(object):
+    """The response class is the way for Sijax functions (handlers) to
+    pass information back to the browser. They do this by calling
+    various methods, which queue commands until they're sent to the browser.
+    """
     
     COMMAND_ALERT = 'alert'
     COMMAND_HTML = 'html'
